#
# spec file for package ossim
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2015 Angelos Tzotsos <tzotsos@opensuse.org>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_ver 2
Name:           ossim
Version:        2.12.0
Release:        1.1
Summary:        Open Source Software Image Map (OSSIM)
License:        LGPL-3.0-only
Group:          Development/Libraries/C and C++
URL:            http://trac.osgeo.org/ossim/
Source0:        https://github.com/ossimlabs/ossim/releases/download/v%{version}/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM ossim-long-int-cast.patch gh#ossimlabs/ossim#301 badshah400@gmail.com -- Explicitly cast hsize_t into u_int64 to avoid compilation problems with hdf5 >= 1.14.0
Patch0:         ossim-long-int-cast.patch
BuildRequires:  cmake >= 2.8.0
BuildRequires:  fdupes
BuildRequires:  freetype2-devel
BuildRequires:  gcc-c++
BuildRequires:  geos-devel
BuildRequires:  geotiff-devel
BuildRequires:  hdf5-devel
BuildRequires:  jsoncpp-devel
BuildRequires:  libOpenThreads-devel
BuildRequires:  libcurl-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libtiff-devel
BuildRequires:  zlib-devel

%description
The OSSIM core utilities.
Open Source Software Image Map (OSSIM) is an engine for
remote sensing, image processing, geographical information systems and
photogrammetry.

%package devel
Summary:        Header files for the Open Source Software Image Map
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{so_ver} = %{version}-%{release}
Provides:       lib%{name}-devel

%description devel
The OSSIM development files.
Open Source Software Image Map (OSSIM) is an engine for
remote sensing, image processing, geographical information systems and
photogrammetry.

%package -n lib%{name}%{so_ver}
Summary:        Open Source Software Image Map libraries
Group:          System/Libraries

%description -n lib%{name}%{so_ver}
The OSSIM shared library files.
Open Source Software Image Map (OSSIM) is an engine for
remote sensing, image processing, geographical information systems and
photogrammetry.

%package sample-data
Summary:        OSSIM data samples files
Group:          Development/Libraries/C and C++
BuildArch:      noarch

%description sample-data
The OSSIM data samples files for tests.

%prep
%autosetup -p1

%build
%cmake \
  -DINSTALL_LIBRARY_DIR=%{_libdir} \
  -DBUILD_OSSIM_FRAMEWORKS=ON \
  -DBUILD_OSSIM_FREETYPE_SUPPORT=ON \
  -DBUILD_OSSIM_MPI_SUPPORT=OFF \
  -DBUILD_OSSIM_ID_SUPPORT=ON \
  -DBUILD_OSSIM_APPS=ON \
  -DBUILD_OSSIM_CURL_APPS=OFF \
  -DBUILD_OSSIM_TESTS=ON \
  -DBUILD_OSSIM_HDF5_SUPPORT=ON \
  -DBUILD_SHARED_LIBS=ON

%cmake_build

%install
%cmake_install

%fdupes %{buildroot}/%{_prefix}

%ldconfig_scriptlets -n lib%{name}%{so_ver}

%files -n lib%{name}%{so_ver}
%{_libdir}/*.so.%{so_ver}*

%files
%{_bindir}/*

%files devel
%{_includedir}/*
%{_libdir}/lib*.so

%files sample-data
%{_datadir}/ossim/

%changelog
* Wed Mar 26 2025 Atri <badshah400@gmail.com>
- Fix devel package requirement on shared lib after the latter's
  so version bump.
* Sat Mar  8 2025 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.12.0:
  * No release notes.
- Add ossim-long-int-cast.patch: explicitly cast hsize_t to
  u_int64 to avoid compilation problem with hdf5 >= 1.14.0
  [gh#ossimlabs/ossim#301].
- Pass INSTALL_LIBRARY_DIR=%%{_libdir} to avoid having to move
  installed arch-specific library dirs after install.
- Use %%ldconfig_scriptlets instead of `post(un) -p
  /sbin/ldconfig`.
* Thu Feb 20 2020 Dirk Stoecker <opensuse@dstoecker.de>
- update to 2.11.1
- drop fix_hdf5_printErrorStack.patch (fixed upstream)
* Sat Jul  6 2019 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of descriptions. Trim history from
  descriptions.
- Limit fdupes to the /usr subvolume.
* Fri Mar 22 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Switch from geos35 to geos as there is no more build problem
  with Leap 42.3, it also fixes build on Leap 15.0
* Sun Sep 30 2018 Bruno Friedmann <bruno@ioda-net.ch>
- Update to last 2.5.1 version (Islamorada)
- Packaging:
  + spec-cleaner minimal, but don't let it play with the manual
    patching for lib(64)
  + add patch fix_hdf5_printErrorStack.patch to replace deprecated
    and removed printError() function in hdf5 1.10.2+
* Sat Sep 29 2018 Bruno Friedmann <bruno@ioda-net.ch>
- Fix build with Tumbleweed (force use of '-std=c++03')
  Backport old patch lost during transfert in App:Geo from
  Staging
* Tue May 29 2018 guillaume.gardet@opensuse.org
- Update to 2.3.2
- Drop cmake.patch
* Mon Nov 13 2017 guillaume@opensuse.org
- Update to 2.1.0 (lib version 1.9.0)
* Mon Nov 13 2017 guillaume@opensuse.org
- Fix build with Tumbleweed (force use of '-std=c++03')
* Wed Jun 28 2017 guillaume@opensuse.org
- Update cmake.patch to match 1.8.20.3 version (instead of old
  1.8.18.1)
* Tue Jun 27 2017 guillaume@opensuse.org
- Build against geos 3.5 (instead of 3.6) to fix openSUSE Leap 42.x
  builds
* Sun Dec 27 2015 mpluskal@suse.com
- Use cmake macros
- Shorten summary
- Do not ship static library
* Wed Dec 23 2015 Angelos Tzotsos <tzotsos@opensuse.org>
- Update to 1.8.20
* Fri Aug 14 2015 Angelos Tzotsos <tzotsos@opensuse.org>
- Initial build
- Patch cmake.patch to allow proper cmake build
